@@ -1,10 +1,10 @@
 library(directlabels)
-data(prostate,package="ElemStatLearn")
+data(prostate)
 pros <- subset(prostate,select=-train,train==TRUE)
 ycol <- which(names(pros)=="lpsa")
 x <- as.matrix(pros[-ycol])
 y <- pros[[ycol]]
-library(lars)
+if(require(lars) && require(ggplot2)) withAutoprint({
 fit <- lars(x,y,type="lasso")
 beta <- scale(coef(fit),FALSE,1/fit$normx)
 
@@ -16,7 +16,6 @@ path <- data.frame(
   variable=colnames(beta)[as.integer(col(beta))],
   arclength=arclength[as.integer(row(beta))],
   standardized.coef=as.numeric(beta))
-library(ggplot2)
 p <- ggplot(path,aes(arclength,standardized.coef,colour=variable))+
   geom_line(aes(group=variable))+
   ggtitle("LASSO path for prostate cancer data calculated using the LARS")+
@@ -34,4 +33,4 @@ p <- ggplot(path,aes(step,standardized.coef,colour=variable))+
   ggtitle("LASSO path for prostate cancer data calculated using the LARS")+
   xlim(0,20)
 print(direct.label(p,"lasso.labels"))
-  
+})
